@@ -18,8 +18,6 @@ Provides Arbitrary instances for:
 
 * Word8 (also a Random instance)
 
-* Char (bounded between chars 0 and 255)
-
 Written by John Goerzen, jgoerzen\@complete.org
 -}
 
@@ -34,10 +32,14 @@ instance (Arbitrary k, Arbitrary v, Eq k, Ord k) => Arbitrary (Map.Map k v) wher
     arbitrary = 
         do items <- arbitrary
            return $ Map.fromList items
+
+instance (CoArbitrary k, CoArbitrary v, Eq k, Ord k) => CoArbitrary (Map.Map k v) where
     coarbitrary = coarbitrary . Map.keys
 
 instance Arbitrary Word8 where
     arbitrary = sized $ \n -> choose (0, min (fromIntegral n) maxBound)
+
+instance CoArbitrary Word8 where
     coarbitrary n = variant (if n >= 0 then 2 * x else 2 * x + 1)
                 where x = abs . fromIntegral $ n
 
@@ -46,8 +48,3 @@ instance Random Word8 where
                        randomR (toInteger a, toInteger b) g
     random g = randomR (minBound, maxBound) g
 
-instance Arbitrary Char where
-    arbitrary = sized $ \n -> choose ('\NUL', '\xFF')
-    coarbitrary n = variant (toEnum (2 * x + 1))
-                where x = (abs . fromEnum $ n)::Int
-
